% This file contains code that performs all variance decomposition exercises. 
% There are three accompanying .txt files that contain all inputs to run
% the code. The inputs are: (i) All variables used to obtain results in
% Tables 5, 6, 7, and 22 in the main text and Supplementary Appendix V; (ii)
% all coefficient estimates and residuals from linear regressions whose
% results are reported in the same tables. The code and data files to
% replicate the regression results are contained in mango_code.do file.

clear all

clc

% Load file that contains all variables, including residuals. Notation is
% as follows: res_bench_icp is the residual (res) obtained from benchmark regression in Table 5 of paper corresponding
% to single purchase prices (bench), where the measure of market share is obtained
% using ICP data (icp). Similarly, go corresponds to the measure of market
% share obtained using gross output data,and pop corresponds to the measure
% of market share using population size data. Next, dist corresponds to
% specifications reported in the three left panels of Table 6, which use a
% distance polynomial. ek corresponds to the specifications reported in the
% three right panels of Table 6, which use distance regions a la Eaton and
% Kortum. min corresponds to the specifications that use shipping cost
% minimizer prices reported in Table 7. Finally web corresponds to the
% specifications that use web listed prices reported in Table 22.

load data_decomp_may_2014.txt

res_bench_icp=data_decomp_may_2014(:,1);
res_bench_go=data_decomp_may_2014(:,2);
res_bench_pop=data_decomp_may_2014(:,3);
res_dist_icp=data_decomp_may_2014(:,4);
res_dist_go=data_decomp_may_2014(:,5);
res_dist_pop=data_decomp_may_2014(:,6);
res_ek_icp=data_decomp_may_2014(:,7);
res_ek_go=data_decomp_may_2014(:,8);
res_ek_pop=data_decomp_may_2014(:,9);
res_min_icp=data_decomp_may_2014(:,10);
res_min_go=data_decomp_may_2014(:,11);
res_min_pop=data_decomp_may_2014(:,12);
res_web_icp=data_decomp_may_2014(:,13);
res_web_go=data_decomp_may_2014(:,14);
res_web_pop=data_decomp_may_2014(:,15);

% Remaining variables are described in line

log_p_web=data_decomp_may_2014(:,16);%log price of item relative to spain, web listed
log_pcy=data_decomp_may_2014(:,17);% log gdp per capita, relative to spain
log_pop=data_decomp_may_2014(:,18);% log population, relative to spain
log_vat=data_decomp_may_2014(:,19);% log gross sales tax, relative to spain
rta=data_decomp_may_2014(:,20);% 1 if RTA with spain, zero otherwise
euro=data_decomp_may_2014(:,21);% 1 if Mango prices listed in Euro, 0 otherwise
log_dist=data_decomp_may_2014(:,22);% log distance from Spain
log_dist_2=data_decomp_may_2014(:,23);% above squared
log_dist_3=data_decomp_may_2014(:,24);% above cubed
log_p_single=data_decomp_may_2014(:,25);%log price of item relative to spain, single item purchase
log_dhl=data_decomp_may_2014(:,26);% log dhl shipping cost, relative to spain
landlocked=data_decomp_may_2014(:,27);% 1 if country is landlocked, zero otherwise
log_gini=data_decomp_may_2014(:,28);% log gini coefficient, relative to spain
log_go=data_decomp_may_2014(:,29);% log market share, relative to spain, go measure
island=data_decomp_may_2014(:,30);% 1 if country is island, zero otherwise
log_p_min=data_decomp_may_2014(:,31);%log price of item relative to spain, shipping cost minimizers
log_icp=data_decomp_may_2014(:,32);% log market share, relative to spain, icp measure
returnslocal=data_decomp_may_2014(:,33);% 1 if Mango accepts returns at local address via mail
pickup=data_decomp_may_2014(:,34);% 1 if Mango accepts returns via third-party home pick up
store=data_decomp_may_2014(:,35);% 1 if Mango accepts returns in any local store
limstore=data_decomp_may_2014(:,36);% 1 if Mango accepts returns at single/limited store
ek1=data_decomp_may_2014(:,37);% 1 if country is in distance region 1, zero otherwise
ek2=data_decomp_may_2014(:,38);% 1 if country is in distance region 2, zero otherwise
ek3=data_decomp_may_2014(:,39);% 1 if country is in distance region 3, zero otherwise

% Load coefficient estimates from specifications in Tables 5 (1.-3. below),
% 7 (4.-6. below), and 22 (7.-.9 below)

% columns
% 1. log_p_single_icp 
% 2. log_p_single_go 
% 3. log_p_single_pop 
% 4. log_p_min_icp 
% 5. log_p_min_go 
% 6. log_p_min_pop
% 7. log_p_web_icp 
% 8. log_p_web_go 
% 9. log_p_web_pop

%Each row in the matrix corresponds to the coefficient estimate of the
%following variable:

%1. log_gdp_cur_2010 
%2. trade_share_icp /go/pop
%3. log_vat 
%4. euro 
%5. dhl_log
%6. returnslocal
%7. pickup
%8. store
%9. limstore
%10.log_gini 

load betas_bench_decomp_may_2014.txt



% Load coefficient estimates from specifications in Table 6

% columns
% 1. log_p_single_icp_dist 
% 2. log_p_single_go_dist 
% 3. log_p_single_pop_dist 
% 4. log_p_single_icp_ek 
% 5. log_p_single_go_ek 
% 6. log_p_single_pop_ek 

%Each row in the matrix corresponds to the coefficient estimate of the
%following variable:
%1. log_gdp_cur_2010 
%2. trade_share_icp /go/pop
%3. log_vat 
%4. euro 
%5. dhl_log
%6. returnslocal
%7. pickup
%8. store
%9. limstore
%10. log_gini 
%11. landlocked
%12.island
%13. rta
%14. log_dist/ek1
%15. log_dist_2/ek2
%16. log_dist_3/ek3

load betas_dist_decomp_may_2014.txt

% Variance decomposition methodology follows Crucini and Yilmazkuday (2014)
% and is described in main text of paper.
% cov: row is obs, column is var

% ONE ITEM PURCHASES

var_bench=var(log_p_single);

% ICP

betaX_bench_icp=[log_pcy*betas_bench_decomp_may_2014(1,1)...
    log_icp*betas_bench_decomp_may_2014(2,1)...
               log_vat*betas_bench_decomp_may_2014(3,1)...
               euro*betas_bench_decomp_may_2014(4,1)...
               log_dhl*betas_bench_decomp_may_2014(5,1)...
               returnslocal*betas_bench_decomp_may_2014(6,1)...
               pickup*betas_bench_decomp_may_2014(7,1)...
               store*betas_bench_decomp_may_2014(8,1)...
               limstore*betas_bench_decomp_may_2014(9,1)...
               log_gini*betas_bench_decomp_may_2014(10,1)...
               res_bench_icp];
           
cov_bench_icp=cov(betaX_bench_icp); 

diag_bench_icp=diag(cov_bench_icp);


'The variance decomposition for benchmark icp model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
bench_icp=[diag_bench_icp(1)/var_bench diag_bench_icp(2)/var_bench diag_bench_icp(3)/var_bench...
                  diag_bench_icp(4)/var_bench diag_bench_icp(5)/var_bench...
                  diag_bench_icp(6)/var_bench diag_bench_icp(7)/var_bench...
                  diag_bench_icp(8)/var_bench diag_bench_icp(9)/var_bench...
                  diag_bench_icp(10)/var_bench diag_bench_icp(11)/var_bench]
'these account for x% of entire variance'              
              sum(bench_icp(1:10))

              % GO
              
betaX_bench_go=[log_pcy*betas_bench_decomp_may_2014(1,2)...
    log_go*betas_bench_decomp_may_2014(2,2)...
               log_vat*betas_bench_decomp_may_2014(3,2)...
               euro*betas_bench_decomp_may_2014(4,2)...
               log_dhl*betas_bench_decomp_may_2014(5,2)...
               returnslocal*betas_bench_decomp_may_2014(6,2)...
               pickup*betas_bench_decomp_may_2014(7,2)...
               store*betas_bench_decomp_may_2014(8,2)...
               limstore*betas_bench_decomp_may_2014(9,2)...
               log_gini*betas_bench_decomp_may_2014(10,2)...
               res_bench_go];
           
          
           
cov_bench_go=cov(betaX_bench_go); 

diag_bench_go=diag(cov_bench_go);

'The variance decomposition for benchmark go model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
bench_go=[diag_bench_go(1)/var_bench diag_bench_go(2)/var_bench diag_bench_go(3)/var_bench...
                  diag_bench_go(4)/var_bench diag_bench_go(5)/var_bench...
                  diag_bench_go(6)/var_bench diag_bench_go(7)/var_bench...
                  diag_bench_go(8)/var_bench diag_bench_go(9)/var_bench...
                  diag_bench_go(10)/var_bench diag_bench_go(11)/var_bench]
              'these account for x% of entire variance'              
              sum(bench_go(1:10))
              
          % POP
              
betaX_bench_pop=[log_pcy*betas_bench_decomp_may_2014(1,3)...
    log_pop*betas_bench_decomp_may_2014(2,3)...
               log_vat*betas_bench_decomp_may_2014(3,3)...
               euro*betas_bench_decomp_may_2014(4,3)...
               log_dhl*betas_bench_decomp_may_2014(5,3)...
               returnslocal*betas_bench_decomp_may_2014(6,3)...
               pickup*betas_bench_decomp_may_2014(7,3)...
               store*betas_bench_decomp_may_2014(8,3)...
               limstore*betas_bench_decomp_may_2014(9,3)...
               log_gini*betas_bench_decomp_may_2014(10,3)...
               res_bench_pop];
           
          
           
cov_bench_pop=cov(betaX_bench_pop); 

diag_bench_pop=diag(cov_bench_pop);

'The variance decomposition for benchmark pop model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
bench_pop=[diag_bench_pop(1)/var_bench diag_bench_pop(2)/var_bench diag_bench_pop(3)/var_bench...
                  diag_bench_pop(4)/var_bench diag_bench_pop(5)/var_bench...
                  diag_bench_pop(6)/var_bench diag_bench_pop(7)/var_bench...
                  diag_bench_pop(8)/var_bench diag_bench_pop(9)/var_bench...
                  diag_bench_pop(10)/var_bench diag_bench_pop(11)/var_bench]
              'these account for x% of entire variance'              
              sum(bench_pop(1:10))
              
              
        % DISTANCE      
        
        var_dist=var_bench;
              
              
              betaX_dist_icp=[log_pcy*betas_dist_decomp_may_2014(1,1)...
    log_icp*betas_dist_decomp_may_2014(2,1)...
               log_vat*betas_dist_decomp_may_2014(3,1)...
               euro*betas_dist_decomp_may_2014(4,1)...
               log_dhl*betas_dist_decomp_may_2014(5,1)...
               returnslocal*betas_dist_decomp_may_2014(6,1)...
               pickup*betas_dist_decomp_may_2014(7,1)...
               store*betas_dist_decomp_may_2014(8,1)...
               limstore*betas_dist_decomp_may_2014(9,1)...
               log_gini*betas_dist_decomp_may_2014(10,1)...
               landlocked*betas_dist_decomp_may_2014(11,1)...
               island*betas_dist_decomp_may_2014(12,1)...
               rta*betas_dist_decomp_may_2014(13,1)...
               log_dist*betas_dist_decomp_may_2014(14,1)...
               log_dist_2*betas_dist_decomp_may_2014(15,1)...
               log_dist_3*betas_dist_decomp_may_2014(16,1)...
               res_dist_icp];
           
cov_dist_icp=cov(betaX_dist_icp); 

diag_dist_icp=diag(cov_dist_icp);


'The variance decomposition for distmark icp model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11.landlocked, 12. island'
'13. rta 14. dist 15. dist2 16. dist3 17.res '
dist_icp=[diag_dist_icp(1)/var_dist diag_dist_icp(2)/var_dist diag_dist_icp(3)/var_dist...
                  diag_dist_icp(4)/var_dist diag_dist_icp(5)/var_dist...
                  diag_dist_icp(6)/var_dist diag_dist_icp(7)/var_dist...
                  diag_dist_icp(8)/var_dist diag_dist_icp(9)/var_dist...
                  diag_dist_icp(10)/var_dist diag_dist_icp(11)/var_dist...
                  diag_dist_icp(12)/var_dist diag_dist_icp(13)/var_dist]
                 [diag_dist_icp(14)/var_dist diag_dist_icp(15)/var_dist...
                  diag_dist_icp(16)/var_dist diag_dist_icp(17)/var_dist]
'these account for x% of entire variance'              
              sum(dist_icp(1:13))

              % GO
              
betaX_dist_go=[log_pcy*betas_dist_decomp_may_2014(1,2)...
    log_go*betas_dist_decomp_may_2014(2,2)...
               log_vat*betas_dist_decomp_may_2014(3,2)...
               euro*betas_dist_decomp_may_2014(4,2)...
               log_dhl*betas_dist_decomp_may_2014(5,2)...
               returnslocal*betas_dist_decomp_may_2014(6,2)...
               pickup*betas_dist_decomp_may_2014(7,2)...
               store*betas_dist_decomp_may_2014(8,2)...
               limstore*betas_dist_decomp_may_2014(9,2)...
               log_gini*betas_dist_decomp_may_2014(10,2)...
               landlocked*betas_dist_decomp_may_2014(11,2)...
               island*betas_dist_decomp_may_2014(12,2)...
               rta*betas_dist_decomp_may_2014(13,2)...
               log_dist*betas_dist_decomp_may_2014(14,2)...
               log_dist_2*betas_dist_decomp_may_2014(15,2)...
               log_dist_3*betas_dist_decomp_may_2014(16,2)...
               res_dist_go];
           
          
           
cov_dist_go=cov(betaX_dist_go); 

diag_dist_go=diag(cov_dist_go);

'The variance decomposition for distmark go model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11.landlocked, 12. island'
'13. rta 14. dist 15. dist2 16. dist3 17.res '
dist_go=[diag_dist_go(1)/var_dist diag_dist_go(2)/var_dist diag_dist_go(3)/var_dist...
                  diag_dist_go(4)/var_dist diag_dist_go(5)/var_dist...
                  diag_dist_go(6)/var_dist diag_dist_go(7)/var_dist...
                  diag_dist_go(8)/var_dist diag_dist_go(9)/var_dist...
                  diag_dist_go(10)/var_dist diag_dist_go(11)/var_dist...
                  diag_dist_go(12)/var_dist diag_dist_go(13)/var_dist]
                  [diag_dist_go(14)/var_dist diag_dist_go(15)/var_dist...
                  diag_dist_go(16)/var_dist diag_dist_go(17)/var_dist]
              'these account for x% of entire variance'              
              sum(dist_go(1:13))
              
          % POP
              
betaX_dist_pop=[log_pcy*betas_dist_decomp_may_2014(1,3)...
    log_pop*betas_dist_decomp_may_2014(2,3)...
               log_vat*betas_dist_decomp_may_2014(3,3)...
               euro*betas_dist_decomp_may_2014(4,3)...
               log_dhl*betas_dist_decomp_may_2014(5,3)...
               returnslocal*betas_dist_decomp_may_2014(6,3)...
               pickup*betas_dist_decomp_may_2014(7,3)...
               store*betas_dist_decomp_may_2014(8,3)...
               limstore*betas_dist_decomp_may_2014(9,3)...
               log_gini*betas_dist_decomp_may_2014(10,3)...
               landlocked*betas_dist_decomp_may_2014(11,3)...
               island*betas_dist_decomp_may_2014(12,3)...
               rta*betas_dist_decomp_may_2014(13,3)...
               log_dist*betas_dist_decomp_may_2014(14,3)...
               log_dist_2*betas_dist_decomp_may_2014(15,3)...
               log_dist_3*betas_dist_decomp_may_2014(16,3)...
               res_dist_pop];
           
          
           
cov_dist_pop=cov(betaX_dist_pop); 

diag_dist_pop=diag(cov_dist_pop);

'The variance decomposition for distmark pop model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11.landlocked, 12. island'
'13. rta 14. dist 15. dist2 16. dist3 17.res '
dist_pop=[diag_dist_pop(1)/var_dist diag_dist_pop(2)/var_dist diag_dist_pop(3)/var_dist...
                  diag_dist_pop(4)/var_dist diag_dist_pop(5)/var_dist...
                  diag_dist_pop(6)/var_dist diag_dist_pop(7)/var_dist...
                  diag_dist_pop(8)/var_dist diag_dist_pop(9)/var_dist...
                  diag_dist_pop(10)/var_dist diag_dist_pop(11)/var_dist...
                  diag_dist_pop(12)/var_dist diag_dist_pop(13)/var_dist]
                  [diag_dist_pop(14)/var_dist diag_dist_pop(15)/var_dist...
                  diag_dist_pop(16)/var_dist diag_dist_pop(17)/var_dist]
              'these account for x% of entire variance'              
              sum(dist_pop(1:13))
              
              
              
              % EK      
        
        var_ek=var_bench;
              
              
              betaX_ek_icp=[log_pcy*betas_dist_decomp_may_2014(1,4)...
    log_icp*betas_dist_decomp_may_2014(2,4)...
               log_vat*betas_dist_decomp_may_2014(3,4)...
               euro*betas_dist_decomp_may_2014(4,4)...
               log_dhl*betas_dist_decomp_may_2014(5,4)...
               returnslocal*betas_dist_decomp_may_2014(6,4)...
               pickup*betas_dist_decomp_may_2014(7,4)...
               store*betas_dist_decomp_may_2014(8,4)...
               limstore*betas_dist_decomp_may_2014(9,4)...
               log_gini*betas_dist_decomp_may_2014(10,4)...
               landlocked*betas_dist_decomp_may_2014(11,4)...
               island*betas_dist_decomp_may_2014(12,4)...
               rta*betas_dist_decomp_may_2014(13,4)...
               ek1*betas_dist_decomp_may_2014(14,4)...
               ek2*betas_dist_decomp_may_2014(15,4)...
               ek3*betas_dist_decomp_may_2014(16,4)...
               res_ek_icp];
           
cov_ek_icp=cov(betaX_ek_icp); 

diag_ek_icp=diag(cov_ek_icp);


'The variance decomposition for ekmark icp model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11.landlocked, 12. island'
'13. rta 14. ek 15. ek2 16. ek3 17.res '
ek_icp=[diag_ek_icp(1)/var_ek diag_ek_icp(2)/var_ek diag_ek_icp(3)/var_ek...
                  diag_ek_icp(4)/var_ek diag_ek_icp(5)/var_ek...
                  diag_ek_icp(6)/var_ek diag_ek_icp(7)/var_ek...
                  diag_ek_icp(8)/var_ek diag_ek_icp(9)/var_ek...
                  diag_ek_icp(10)/var_ek diag_ek_icp(11)/var_ek...
                  diag_ek_icp(12)/var_ek diag_ek_icp(13)/var_ek...
                 diag_ek_icp(14)/var_ek diag_ek_icp(15)/var_ek...
                  diag_ek_icp(16)/var_ek diag_ek_icp(17)/var_ek]
'these account for x% of entire variance'              
              sum(ek_icp(1:16))

              % GO
              
betaX_ek_go=[log_pcy*betas_dist_decomp_may_2014(1,5)...
    log_go*betas_dist_decomp_may_2014(2,5)...
               log_vat*betas_dist_decomp_may_2014(3,5)...
               euro*betas_dist_decomp_may_2014(4,5)...
               log_dhl*betas_dist_decomp_may_2014(5,5)...
               returnslocal*betas_dist_decomp_may_2014(6,5)...
               pickup*betas_dist_decomp_may_2014(7,5)...
               store*betas_dist_decomp_may_2014(8,5)...
               limstore*betas_dist_decomp_may_2014(9,5)...
               log_gini*betas_dist_decomp_may_2014(10,5)...
               landlocked*betas_dist_decomp_may_2014(11,5)...
               island*betas_dist_decomp_may_2014(12,5)...
               rta*betas_dist_decomp_may_2014(13,5)...
               ek1*betas_dist_decomp_may_2014(14,5)...
               ek2*betas_dist_decomp_may_2014(15,5)...
               ek3*betas_dist_decomp_may_2014(16,5)...
               res_ek_go];
           
          
           
cov_ek_go=cov(betaX_ek_go); 

diag_ek_go=diag(cov_ek_go);

'The variance decomposition for ekmark go model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11.landlocked, 12. island'
'13. rta 14. ek 15. ek2 16. ek3 17.res '
ek_go=[diag_ek_go(1)/var_ek diag_ek_go(2)/var_ek diag_ek_go(3)/var_ek...
                  diag_ek_go(4)/var_ek diag_ek_go(5)/var_ek...
                  diag_ek_go(6)/var_ek diag_ek_go(7)/var_ek...
                  diag_ek_go(8)/var_ek diag_ek_go(9)/var_ek...
                  diag_ek_go(10)/var_ek diag_ek_go(11)/var_ek...
                  diag_ek_go(12)/var_ek diag_ek_go(13)/var_ek...
                  diag_ek_go(14)/var_ek diag_ek_go(15)/var_ek...
                  diag_ek_go(16)/var_ek diag_ek_go(17)/var_ek]
              'these account for x% of entire variance'              
              sum(ek_go(1:16))
              
          % POP
              
betaX_ek_pop=[log_pcy*betas_dist_decomp_may_2014(1,6)...
    log_pop*betas_dist_decomp_may_2014(2,6)...
               log_vat*betas_dist_decomp_may_2014(3,6)...
               euro*betas_dist_decomp_may_2014(4,6)...
               log_dhl*betas_dist_decomp_may_2014(5,6)...
               returnslocal*betas_dist_decomp_may_2014(6,6)...
               pickup*betas_dist_decomp_may_2014(7,6)...
               store*betas_dist_decomp_may_2014(8,6)...
               limstore*betas_dist_decomp_may_2014(9,6)...
               log_gini*betas_dist_decomp_may_2014(10,6)...
               landlocked*betas_dist_decomp_may_2014(11,6)...
               island*betas_dist_decomp_may_2014(12,6)...
               rta*betas_dist_decomp_may_2014(13,6)...
               ek1*betas_dist_decomp_may_2014(14,6)...
               ek2*betas_dist_decomp_may_2014(15,6)...
               ek3*betas_dist_decomp_may_2014(16,6)...
               res_ek_pop];
           
          
           
cov_ek_pop=cov(betaX_ek_pop); 

diag_ek_pop=diag(cov_ek_pop);

'The variance decomposition for ekmark pop model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11.landlocked, 12. island'
'13. rta 14. ek 15. ek2 16. ek3 17.res '
ek_pop=[diag_ek_pop(1)/var_ek diag_ek_pop(2)/var_ek diag_ek_pop(3)/var_ek...
                  diag_ek_pop(4)/var_ek diag_ek_pop(5)/var_ek...
                  diag_ek_pop(6)/var_ek diag_ek_pop(7)/var_ek...
                  diag_ek_pop(8)/var_ek diag_ek_pop(9)/var_ek...
                  diag_ek_pop(10)/var_ek diag_ek_pop(11)/var_ek...
                  diag_ek_pop(12)/var_ek diag_ek_pop(13)/var_ek...
                  diag_ek_pop(14)/var_ek diag_ek_pop(15)/var_ek...
                  diag_ek_pop(16)/var_ek diag_ek_pop(17)/var_ek]
              'these account for x% of entire variance'              
              sum(ek_pop(1:16))
              
              
              
              
              % SHIPPING COST MINIMIZERS
              
              var_min=var(log_p_min);
              
              %ICP
             
           
              betaX_min_icp=[log_pcy*betas_bench_decomp_may_2014(1,4)...
    log_icp*betas_bench_decomp_may_2014(2,4)...
               log_vat*betas_bench_decomp_may_2014(3,4)...
               euro*betas_bench_decomp_may_2014(4,4)...
               log_dhl*betas_bench_decomp_may_2014(5,4)...
               returnslocal*betas_bench_decomp_may_2014(6,4)...
               pickup*betas_bench_decomp_may_2014(7,4)...
               store*betas_bench_decomp_may_2014(8,4)...
               limstore*betas_bench_decomp_may_2014(9,4)...
               log_gini*betas_bench_decomp_may_2014(10,4)...
               res_min_icp];
           
cov_min_icp=cov(betaX_min_icp); 

diag_min_icp=diag(cov_min_icp);


'The variance decomposition for minmark icp model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
min_icp=[diag_min_icp(1)/var_min diag_min_icp(2)/var_min diag_min_icp(3)/var_min...
                  diag_min_icp(4)/var_min diag_min_icp(5)/var_min...
                  diag_min_icp(6)/var_min diag_min_icp(7)/var_min...
                  diag_min_icp(8)/var_min diag_min_icp(9)/var_min...
                  diag_min_icp(10)/var_min diag_min_icp(11)/var_min]
'these account for x% of entire variance'              
              sum(min_icp(1:10))

              %GO
betaX_min_go=[log_pcy*betas_bench_decomp_may_2014(1,5)...
    log_go*betas_bench_decomp_may_2014(2,5)...
               log_vat*betas_bench_decomp_may_2014(3,5)...
               euro*betas_bench_decomp_may_2014(4,5)...
               log_dhl*betas_bench_decomp_may_2014(5,5)...
               returnslocal*betas_bench_decomp_may_2014(6,5)...
               pickup*betas_bench_decomp_may_2014(7,5)...
               store*betas_bench_decomp_may_2014(8,5)...
               limstore*betas_bench_decomp_may_2014(9,5)...
               log_gini*betas_bench_decomp_may_2014(10,5)...
               res_min_go];
           
          
           
cov_min_go=cov(betaX_min_go); 

diag_min_go=diag(cov_min_go);

'The variance decomposition for minmark go model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
min_go=[diag_min_go(1)/var_min diag_min_go(2)/var_min diag_min_go(3)/var_min...
                  diag_min_go(4)/var_min diag_min_go(5)/var_min...
                  diag_min_go(6)/var_min diag_min_go(7)/var_min...
                  diag_min_go(8)/var_min diag_min_go(9)/var_min...
                  diag_min_go(10)/var_min diag_min_go(11)/var_min]
              'these account for x% of entire variance'              
              sum(min_go(1:10))
              
          %POP
betaX_min_pop=[log_pcy*betas_bench_decomp_may_2014(1,6)...
    log_pop*betas_bench_decomp_may_2014(2,6)...
               log_vat*betas_bench_decomp_may_2014(3,6)...
               euro*betas_bench_decomp_may_2014(4,6)...
               log_dhl*betas_bench_decomp_may_2014(5,6)...
               returnslocal*betas_bench_decomp_may_2014(6,6)...
               pickup*betas_bench_decomp_may_2014(7,6)...
               store*betas_bench_decomp_may_2014(8,6)...
               limstore*betas_bench_decomp_may_2014(9,6)...
               log_gini*betas_bench_decomp_may_2014(10,6)...
               res_min_pop];
           
          
           
cov_min_pop=cov(betaX_min_pop); 

diag_min_pop=diag(cov_min_pop);

'The variance decomposition for minmark pop model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
min_pop=[diag_min_pop(1)/var_min diag_min_pop(2)/var_min diag_min_pop(3)/var_min...
                  diag_min_pop(4)/var_min diag_min_pop(5)/var_min...
                  diag_min_pop(6)/var_min diag_min_pop(7)/var_min...
                  diag_min_pop(8)/var_min diag_min_pop(9)/var_min...
                  diag_min_pop(10)/var_min diag_min_pop(11)/var_min]
              'these account for x% of entire variance'              
              sum(min_pop(1:10))
              
               % WEB LISTED PRICES
              
              var_web=var(log_p_web);
              
              %ICP
             
           
              betaX_web_icp=[log_pcy*betas_bench_decomp_may_2014(1,7)...
    log_icp*betas_bench_decomp_may_2014(2,7)...
               log_vat*betas_bench_decomp_may_2014(3,7)...
               euro*betas_bench_decomp_may_2014(4,7)...
               log_dhl*betas_bench_decomp_may_2014(5,7)...
               returnslocal*betas_bench_decomp_may_2014(6,7)...
               pickup*betas_bench_decomp_may_2014(7,7)...
               store*betas_bench_decomp_may_2014(8,7)...
               limstore*betas_bench_decomp_may_2014(9,7)...
               log_gini*betas_bench_decomp_may_2014(10,7)...
               res_web_icp];
           
cov_web_icp=cov(betaX_web_icp); 

diag_web_icp=diag(cov_web_icp);


'The variance decomposition for webmark icp model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
web_icp=[diag_web_icp(1)/var_web diag_web_icp(2)/var_web diag_web_icp(3)/var_web...
                  diag_web_icp(4)/var_web diag_web_icp(5)/var_web...
                  diag_web_icp(6)/var_web diag_web_icp(7)/var_web...
                  diag_web_icp(8)/var_web diag_web_icp(9)/var_web...
                  diag_web_icp(10)/var_web diag_web_icp(11)/var_web]
'these account for x% of entire variance'              
              sum(web_icp(1:10))

              %GO
betaX_web_go=[log_pcy*betas_bench_decomp_may_2014(1,8)...
    log_go*betas_bench_decomp_may_2014(2,8)...
               log_vat*betas_bench_decomp_may_2014(3,8)...
               euro*betas_bench_decomp_may_2014(4,8)...
               log_dhl*betas_bench_decomp_may_2014(5,8)...
               returnslocal*betas_bench_decomp_may_2014(6,8)...
               pickup*betas_bench_decomp_may_2014(7,8)...
               store*betas_bench_decomp_may_2014(8,8)...
               limstore*betas_bench_decomp_may_2014(9,8)...
               log_gini*betas_bench_decomp_may_2014(10,8)...
               res_web_go];
           
          
           
cov_web_go=cov(betaX_web_go); 

diag_web_go=diag(cov_web_go);

'The variance decomposition for webmark go model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
web_go=[diag_web_go(1)/var_web diag_web_go(2)/var_web diag_web_go(3)/var_web...
                  diag_web_go(4)/var_web diag_web_go(5)/var_web...
                  diag_web_go(6)/var_web diag_web_go(7)/var_web...
                  diag_web_go(8)/var_web diag_web_go(9)/var_web...
                  diag_web_go(10)/var_web diag_web_go(11)/var_web]
              'these account for x% of entire variance'              
              sum(web_go(1:10))
              
          %POP
betaX_web_pop=[log_pcy*betas_bench_decomp_may_2014(1,9)...
    log_pop*betas_bench_decomp_may_2014(2,9)...
               log_vat*betas_bench_decomp_may_2014(3,9)...
               euro*betas_bench_decomp_may_2014(4,9)...
               log_dhl*betas_bench_decomp_may_2014(5,9)...
               returnslocal*betas_bench_decomp_may_2014(6,9)...
               pickup*betas_bench_decomp_may_2014(7,9)...
               store*betas_bench_decomp_may_2014(8,9)...
               limstore*betas_bench_decomp_may_2014(9,9)...
               log_gini*betas_bench_decomp_may_2014(10,9)...
               res_web_pop];
           
          
           
cov_web_pop=cov(betaX_web_pop); 

diag_web_pop=diag(cov_web_pop);

'The variance decomposition for webmark pop model is: 1. pcy,'
'2. mkt.shr, 3. vat, 4. euro, 5. dhl, 6. retloc, 7. pickup,'
'8. store, 9. limstore, 10.gini, 11. res'
web_pop=[diag_web_pop(1)/var_web diag_web_pop(2)/var_web diag_web_pop(3)/var_web...
                  diag_web_pop(4)/var_web diag_web_pop(5)/var_web...
                  diag_web_pop(6)/var_web diag_web_pop(7)/var_web...
                  diag_web_pop(8)/var_web diag_web_pop(9)/var_web...
                  diag_web_pop(10)/var_web diag_web_pop(11)/var_web]
              'these account for x% of entire variance'              
              sum(web_pop(1:10))